"use client";

import Link from "next/link";
import { useEffect, useState } from "react";
import { usePathname, useSearchParams } from "next/navigation";

import NeedLoginModal from "./needLoginModal";
import { isLoggedIn } from "../handlers/loginHandler";
import {
  getStoredValue,
  removeFromLocalStorage,
} from "../handlers/localStorageHandler";

// Ícones
import FileUploadIcon from '@mui/icons-material/FileUpload';
import CollectionsBookmarkIcon from "@mui/icons-material/CollectionsBookmark";
import SubjectIcon from "@mui/icons-material/Subject";
import EmailRoundedIcon from '@mui/icons-material/EmailRounded';
import LogoutRounded from '@mui/icons-material/LogoutRounded';
import HelpIcon from "@mui/icons-material/Help";
import VerifiedIcon from "@mui/icons-material/Verified";
import { Person } from "@mui/icons-material";
import SearchIcon from '@mui/icons-material/Search';

/**
 * @param {Object} props
 * @param {Function} props.mobileSearch
 */
const navItems = [
  { label: "Pesquisar", href: "#", icon: SearchIcon },
  { label: "perfil", href: "/perfil", icon: Person },
  { label: "Coleções", href: "Collection", icon: CollectionsBookmarkIcon },
  { label: "Recursos", href: "LearningObject", icon: SubjectIcon },
  { label: "Sobre", href: "/sobre", icon: HelpIcon },
  { label: "MEC", href: "MEC", icon: VerifiedIcon },
  { label: "Publicar", href: "/publicar", icon: FileUploadIcon },
  { label: "Contato", href: "/contato", icon: EmailRoundedIcon },
  { label: "Sair", href: "/logout", icon: LogoutRounded },
];

export default function NavigationBar({ mobileSearch }) {
  const [id, setId] = useState(null);
  const [needLoginOpen, setNeedLoginOpen] = useState(false);
  const [loggedIn, setLoggedIn] = useState(false);

  const pathname = usePathname();
  const searchParams = useSearchParams();
  const page = searchParams.get('page');

  useEffect(() => {
    if (isLoggedIn()) {
      const userData = getStoredValue("user_data");
      setLoggedIn(true);
      if (userData) {
        const data = JSON.parse(userData);
        setId(data["id"]);
      }
    }
  }, []);

  const handleLogout = () => {
    removeFromLocalStorage("access_token");
    removeFromLocalStorage("user_data");
    removeFromLocalStorage("uid");
    removeFromLocalStorage("expiry");
    removeFromLocalStorage("token-type");
    removeFromLocalStorage("client");
    window.location.reload();
  };

  const handleOpenLogin = () => {
    if (!isLoggedIn()) {
      setNeedLoginOpen(true);
    }
  };

  const handleToggleMobileSearch = () => {
    mobileSearch.setSearchIsClicked((prev) => !prev);
  };

  const getHref = (href) => {
    if (href === "/publicar" || href === "/sobre" || href === "/contato") return href;
    if (href === "/perfil") return `/perfil/${id}`;
    if (href === "#") return "#";
    return `/busca?page=${href}`;
  };

  return (
    <>
      <NeedLoginModal open={needLoginOpen} setOpen={setNeedLoginOpen} />

      <nav className="bg-lightGray-HC-dark  h-50 outline outline-1 outline-ice-HC-white text-darkGray-HC-white-underline font-light fixed bottom-0 left-0 w-full z-10">
        <ul className="flex justify-between overflow-x-auto no-scrollbar animate-scrollHint">
          {navItems.map((item, index) => {
            const isActive =
              page === item.href ||
              pathname === item.href ||
              pathname.startsWith(item.href) ||
              (mobileSearch.searchIsClicked && item.label === "Pesquisar");

            const isProtected = item.href === "/publicar" || item.href === "/perfil";

            const handleClick = (e) => {
              if (item.label === "Sair") {
                e.preventDefault();
                handleLogout();
              } else if (item.label === "Pesquisar") {
                e.preventDefault();
                handleToggleMobileSearch();
              } else if (isProtected && !isLoggedIn()) {
                e.preventDefault();
                handleOpenLogin();
              }
            };

            return (
              <li key={index} className="flex w-20 flex-col items-center justify-center p-3">
                <Link
                  href={
                    item.label === "Publicar" && !loggedIn
                      ? "#"
                      : item.label === "perfil" && loggedIn
                      ? `/perfil/${id}`
                      : getHref(item.href)
                  }
                  onClick={handleClick}
                  className={`text-center rounded-md transition-all ${
                    isActive ? "text-lightGray-HC-dark-underline font-bold" : ""
                  }`}
                >
                  <item.icon
                    className={`cursor-pointer text-3xl ${isActive ? "text-darkGray-HC-white-underline" : ""}`}
                  />
                  <span className={`cursor-pointer text-xs ${isActive ? "text-darkGray-HC-white-underline font-bold" : ""}`}>
                    {item.label}
                  </span>
                </Link>
              </li>
            );
          })}
        </ul>
      </nav>
    </>
  );
}
